# frozen_string_literal: true

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!

require "helper"

require "gapic/grpc/service_stub"

require "google/cloud/gaming/v1/realms_service_pb"
require "google/cloud/gaming/v1/realms_service_services_pb"
require "google/cloud/gaming/v1/realms_service"

class ::Google::Cloud::Gaming::V1::RealmsService::ClientTest < Minitest::Test
  class ClientStub
    attr_accessor :call_rpc_count, :requests

    def initialize response, operation, &block
      @response = response
      @operation = operation
      @block = block
      @call_rpc_count = 0
      @requests = []
    end

    def call_rpc *args, **kwargs
      @call_rpc_count += 1

      @requests << @block&.call(*args, **kwargs)

      yield @response, @operation if block_given?

      @response
    end
  end

  def test_list_realms
    # Create GRPC objects.
    grpc_response = ::Google::Cloud::Gaming::V1::ListRealmsResponse.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    parent = "hello world"
    page_size = 42
    page_token = "hello world"
    filter = "hello world"
    order_by = "hello world"

    list_realms_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :list_realms, name
      assert_kind_of ::Google::Cloud::Gaming::V1::ListRealmsRequest, request
      assert_equal "hello world", request["parent"]
      assert_equal 42, request["page_size"]
      assert_equal "hello world", request["page_token"]
      assert_equal "hello world", request["filter"]
      assert_equal "hello world", request["order_by"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, list_realms_client_stub do
      # Create client
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.list_realms({ parent: parent, page_size: page_size, page_token: page_token, filter: filter, order_by: order_by }) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.list_realms parent: parent, page_size: page_size, page_token: page_token, filter: filter, order_by: order_by do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.list_realms ::Google::Cloud::Gaming::V1::ListRealmsRequest.new(parent: parent, page_size: page_size, page_token: page_token, filter: filter, order_by: order_by) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.list_realms({ parent: parent, page_size: page_size, page_token: page_token, filter: filter, order_by: order_by }, grpc_options) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.list_realms(::Google::Cloud::Gaming::V1::ListRealmsRequest.new(parent: parent, page_size: page_size, page_token: page_token, filter: filter, order_by: order_by), grpc_options) do |response, operation|
        assert_kind_of Gapic::PagedEnumerable, response
        assert_equal grpc_response, response.response
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, list_realms_client_stub.call_rpc_count
    end
  end

  def test_get_realm
    # Create GRPC objects.
    grpc_response = ::Google::Cloud::Gaming::V1::Realm.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    name = "hello world"

    get_realm_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :get_realm, name
      assert_kind_of ::Google::Cloud::Gaming::V1::GetRealmRequest, request
      assert_equal "hello world", request["name"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, get_realm_client_stub do
      # Create client
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.get_realm({ name: name }) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.get_realm name: name do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.get_realm ::Google::Cloud::Gaming::V1::GetRealmRequest.new(name: name) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.get_realm({ name: name }, grpc_options) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.get_realm(::Google::Cloud::Gaming::V1::GetRealmRequest.new(name: name), grpc_options) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, get_realm_client_stub.call_rpc_count
    end
  end

  def test_create_realm
    # Create GRPC objects.
    grpc_response = ::Google::Longrunning::Operation.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    parent = "hello world"
    realm_id = "hello world"
    realm = {}

    create_realm_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :create_realm, name
      assert_kind_of ::Google::Cloud::Gaming::V1::CreateRealmRequest, request
      assert_equal "hello world", request["parent"]
      assert_equal "hello world", request["realm_id"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Cloud::Gaming::V1::Realm), request["realm"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, create_realm_client_stub do
      # Create client
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.create_realm({ parent: parent, realm_id: realm_id, realm: realm }) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.create_realm parent: parent, realm_id: realm_id, realm: realm do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.create_realm ::Google::Cloud::Gaming::V1::CreateRealmRequest.new(parent: parent, realm_id: realm_id, realm: realm) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.create_realm({ parent: parent, realm_id: realm_id, realm: realm }, grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.create_realm(::Google::Cloud::Gaming::V1::CreateRealmRequest.new(parent: parent, realm_id: realm_id, realm: realm), grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, create_realm_client_stub.call_rpc_count
    end
  end

  def test_delete_realm
    # Create GRPC objects.
    grpc_response = ::Google::Longrunning::Operation.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    name = "hello world"

    delete_realm_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :delete_realm, name
      assert_kind_of ::Google::Cloud::Gaming::V1::DeleteRealmRequest, request
      assert_equal "hello world", request["name"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, delete_realm_client_stub do
      # Create client
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.delete_realm({ name: name }) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.delete_realm name: name do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.delete_realm ::Google::Cloud::Gaming::V1::DeleteRealmRequest.new(name: name) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.delete_realm({ name: name }, grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.delete_realm(::Google::Cloud::Gaming::V1::DeleteRealmRequest.new(name: name), grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, delete_realm_client_stub.call_rpc_count
    end
  end

  def test_update_realm
    # Create GRPC objects.
    grpc_response = ::Google::Longrunning::Operation.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    realm = {}
    update_mask = {}

    update_realm_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :update_realm, name
      assert_kind_of ::Google::Cloud::Gaming::V1::UpdateRealmRequest, request
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Cloud::Gaming::V1::Realm), request["realm"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Protobuf::FieldMask), request["update_mask"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, update_realm_client_stub do
      # Create client
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.update_realm({ realm: realm, update_mask: update_mask }) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.update_realm realm: realm, update_mask: update_mask do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.update_realm ::Google::Cloud::Gaming::V1::UpdateRealmRequest.new(realm: realm, update_mask: update_mask) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.update_realm({ realm: realm, update_mask: update_mask }, grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.update_realm(::Google::Cloud::Gaming::V1::UpdateRealmRequest.new(realm: realm, update_mask: update_mask), grpc_options) do |response, operation|
        assert_kind_of Gapic::Operation, response
        assert_equal grpc_response, response.grpc_op
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, update_realm_client_stub.call_rpc_count
    end
  end

  def test_preview_realm_update
    # Create GRPC objects.
    grpc_response = ::Google::Cloud::Gaming::V1::PreviewRealmUpdateResponse.new
    grpc_operation = GRPC::ActiveCall::Operation.new nil
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure
    grpc_options = {}

    # Create request parameters for a unary method.
    realm = {}
    update_mask = {}
    preview_time = {}

    preview_realm_update_client_stub = ClientStub.new grpc_response, grpc_operation do |name, request, options:|
      assert_equal :preview_realm_update, name
      assert_kind_of ::Google::Cloud::Gaming::V1::PreviewRealmUpdateRequest, request
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Cloud::Gaming::V1::Realm), request["realm"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Protobuf::FieldMask), request["update_mask"]
      assert_equal Gapic::Protobuf.coerce({}, to: ::Google::Protobuf::Timestamp), request["preview_time"]
      refute_nil options
    end

    Gapic::ServiceStub.stub :new, preview_realm_update_client_stub do
      # Create client
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end

      # Use hash object
      client.preview_realm_update({ realm: realm, update_mask: update_mask, preview_time: preview_time }) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use named arguments
      client.preview_realm_update realm: realm, update_mask: update_mask, preview_time: preview_time do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object
      client.preview_realm_update ::Google::Cloud::Gaming::V1::PreviewRealmUpdateRequest.new(realm: realm, update_mask: update_mask, preview_time: preview_time) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use hash object with options
      client.preview_realm_update({ realm: realm, update_mask: update_mask, preview_time: preview_time }, grpc_options) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Use protobuf object with options
      client.preview_realm_update(::Google::Cloud::Gaming::V1::PreviewRealmUpdateRequest.new(realm: realm, update_mask: update_mask, preview_time: preview_time), grpc_options) do |response, operation|
        assert_equal grpc_response, response
        assert_equal grpc_operation, operation
      end

      # Verify method calls
      assert_equal 5, preview_realm_update_client_stub.call_rpc_count
    end
  end

  def test_configure
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure

    client = block_config = config = nil
    Gapic::ServiceStub.stub :new, nil do
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end
    end

    config = client.configure do |c|
      block_config = c
    end

    assert_same block_config, config
    assert_kind_of ::Google::Cloud::Gaming::V1::RealmsService::Client::Configuration, config
  end

  def test_operations_client
    grpc_channel = GRPC::Core::Channel.new "localhost:8888", nil, :this_channel_is_insecure

    client = nil
    Gapic::ServiceStub.stub :new, nil do
      client = ::Google::Cloud::Gaming::V1::RealmsService::Client.new do |config|
        config.credentials = grpc_channel
      end
    end

    assert_kind_of ::Google::Cloud::Gaming::V1::RealmsService::Operations, client.operations_client
  end
end
